==> igniteui-webcomponents-core-3.2.4.tgz: package/esm2015/lib/ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelItemModelDescriptionMetadata } from "./ListPanelItemModelDescriptionMetadata";
import { ListPanelTemplateItemUpdatingEventArgsDescription } from "./ListPanelTemplateItemUpdatingEventArgsDescription";
/**
 * @hidden
 */
export let ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a == null) {
                ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.c(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
            }
            if (a.g(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.s(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
            ListPanelItemModelDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Model", "ExportedType:ListPanelItemModel");
            a.item("ContentRef", "(w:Content,wf:Content)DataRef");
        }
        static d(a) {
            ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.b(a);
            a.u("ListPanelTemplateItemUpdatingEventArgs", () => new ListPanelTemplateItemUpdatingEventArgsDescription());
            a.t("ListPanelTemplateItemUpdatingEventArgs", ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
        }
    }
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata, 'ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata');
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a = null;
    return ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelItemModelDescriptionMetadata } from "./ListPanelItemModelDescriptionMetadata";
import { ListPanelTemplateItemUpdatingEventArgsDescription } from "./ListPanelTemplateItemUpdatingEventArgsDescription";
/**
 * @hidden
 */
export let ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a == null) {
                ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.c(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
            }
            if (a.j(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
            ListPanelItemModelDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Model", "ExportedType:ListPanelItemModel");
            a.item("ContentRef", "(w:Content,wf:Content)DataRef");
        }
        static d(a) {
            ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.b(a);
            a.aa("ListPanelTemplateItemUpdatingEventArgs", () => new ListPanelTemplateItemUpdatingEventArgsDescription());
            a.z("ListPanelTemplateItemUpdatingEventArgs", ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
        }
    }
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata, 'ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata');
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a = null;
    return ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata;
})();
